@@ -222,7 +222,7 @@ def query_reparse(query, internal_filters=None):
     """query_reparse: reparse the query.
     Returns controls dictionary and re-constructed query dictionary.
     """
-    if not query or not isinstance(query, dict):
+    if not internal_filters and (not query or not isinstance(query, dict)):
         return {}, {}
     new_query = {'__default': {}}
     controls = {
@@ -359,6 +359,9 @@ class ExpressController(RestController):
                  readonly=None,
                  subcontrollers=None,
                  extra_attrs=None,
+                 validators=None,
+                 deseralizers=None,
+                 serializers=None,
                  **kwargs):
         if model is not None:
             self._model_ = model
@@ -390,6 +393,12 @@ class ExpressController(RestController):
             self._permissions_ = permissions
         if subcontrollers is not None:
             self._subcontrollers_ = subcontrollers
+        if validators is not None:
+            self._validators_ = validators
+        if serializers is not None:
+            self._serializers_ = serializers
+        if deseralizers is not None:
+            self._deserializers_ = deseralizers
         if kwargs:
             self._internal_filters_ = kwargs
 
@@ -663,6 +672,16 @@ class ExpressController(RestController):
                     result[k].append(v)
                 else:
                     result[k] = [result[k], v]
+        for k, v in result.items():
+            if isinstance(v, (str, unicode)):
+                if v == 'null':
+                    result[k] = None
+                elif v == 'true':
+                    result[k] = True
+                elif v == 'false':
+                    result[k] = False
+                else:
+                    continue
         return result
 
     @staticmethod
